@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-03-10'; # DATE
-our $VERSION = '0.92'; # VERSION
+our $DATE = '2015-03-17'; # DATE
+our $VERSION = '0.93'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -373,6 +373,7 @@ sub hook_after_get_meta {
             summary => "Run in simulation mode (also via DRY_RUN=1)",
             handler => sub {
                 my ($go, $val, $r) = @_;
+                $log->debugf("[pericmd] Dry-run mode is activated");
                 $r->{dry_run} = 1;
                 #$ENV{VERBOSE} = 1;
             },
@@ -469,7 +470,9 @@ sub run_call {
         $log->tracef("[pericmd] Sending argv to server: %s", $extra{argv});
         $extra{argv} = $r->{orig_argv};
     } else {
-        $extra{args} = $r->{args};
+        my %extra_args;
+        $extra_args{-dry_run} = 1 if $r->{dry_run};
+        $extra{args} = {%extra_args, %{$r->{args}}};
     }
 
     $extra{stream_arg} = 1 if $r->{stream_arg};
@@ -503,7 +506,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 0.92 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-10.
+This document describes version 0.93 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-17.
 
 =head1 SYNOPSIS
 
